@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-main-menu.h"
 #include "gnome-cmd-types.h"
@@ -92,7 +94,7 @@ typedef struct
     NULL }
 
 
-struct _GnomeCmdMainMenuPrivate
+struct GnomeCmdMainMenuPrivate
 {
     GtkWidget *file_menu;
     GtkWidget *edit_menu;
@@ -105,8 +107,9 @@ struct _GnomeCmdMainMenuPrivate
     GtkWidget *help_menu;
 
     GtkWidget *menu_edit_paste;
-    GtkWidget *menu_view_conbuttons;
     GtkWidget *menu_view_toolbar;
+    GtkWidget *menu_view_conbuttons;
+    GtkWidget *menu_view_concombo;
     GtkWidget *menu_view_buttonbar;
     GtkWidget *menu_view_cmdline;
     GtkWidget *menu_view_hidden_files;
@@ -351,7 +354,7 @@ static void update_view_menu (GnomeCmdMainMenu *main_menu);
 
 static void on_switch_orientation (GtkMenuItem *menu_item, GnomeCmdMainMenu *main_menu)
 {
-    gnome_cmd_data_set_list_orientation (!gnome_cmd_data_get_list_orientation ());
+    gnome_cmd_data.list_orientation = !gnome_cmd_data.list_orientation;
 
     gnome_cmd_main_win_update_list_orientation (main_win);
 
@@ -366,7 +369,7 @@ static void update_view_menu (GnomeCmdMainMenu *main_menu)
     GdkPixmap *pm;
     GdkBitmap *bm;
 
-    if (gnome_cmd_data_get_list_orientation ())
+    if (gnome_cmd_data.list_orientation)
     {
         label = g_strdup (_("Switch to Vertical Layout"));
         pm = IMAGE_get_pixmap (PIXMAP_SWITCH_V);
@@ -379,7 +382,7 @@ static void update_view_menu (GnomeCmdMainMenu *main_menu)
         bm = IMAGE_get_mask (PIXMAP_SWITCH_H);
     }
 
-    g_list_foreach (main_menu->priv->view_menuitems, (GFunc)gtk_object_destroy, NULL);
+    g_list_foreach (main_menu->priv->view_menuitems, (GFunc) gtk_object_destroy, NULL);
     g_list_free (main_menu->priv->view_menuitems);
     main_menu->priv->view_menuitems = NULL;
 
@@ -616,12 +619,6 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         MENUTYPE_SEPARATOR,
-        {
-            MENU_TYPE_TOGGLEITEM, _("Show Device Buttons"), "", NULL,
-            (gpointer) view_conbuttons, NULL,
-            GNOME_APP_PIXMAP_NONE, NULL,
-            NULL
-        },
         {
             MENU_TYPE_TOGGLEITEM, _("Show Toolbar"), "", NULL,
             (gpointer) view_toolbar, NULL,
@@ -629,7 +626,19 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         {
-            MENU_TYPE_TOGGLEITEM, _("Show Commandline"), "", NULL,
+            MENU_TYPE_TOGGLEITEM, _("Show Device Buttons"), "", NULL,
+            (gpointer) view_conbuttons, NULL,
+            GNOME_APP_PIXMAP_NONE, NULL,
+            NULL
+        },
+        {
+            MENU_TYPE_TOGGLEITEM, _("Show Device List"), "", NULL,
+            (gpointer) view_concombo, NULL,
+            GNOME_APP_PIXMAP_NONE, NULL,
+            NULL
+        },
+        {
+            MENU_TYPE_TOGGLEITEM, _("Show Command Line"), "", NULL,
             (gpointer) view_cmdline, NULL,
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
@@ -821,33 +830,37 @@ static void init (GnomeCmdMainMenu *main_menu)
     gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), main_menu->priv->help_menu);
 
     main_menu->priv->menu_edit_paste = edit_menu_uiinfo[2].widget;
-    main_menu->priv->menu_view_conbuttons = view_menu_uiinfo[4].widget;
-    main_menu->priv->menu_view_toolbar = view_menu_uiinfo[5].widget;
-    main_menu->priv->menu_view_cmdline = view_menu_uiinfo[6].widget;
-    main_menu->priv->menu_view_buttonbar = view_menu_uiinfo[7].widget;
-    main_menu->priv->menu_view_hidden_files = view_menu_uiinfo[9].widget;
-    main_menu->priv->menu_view_backup_files = view_menu_uiinfo[10].widget;
+    main_menu->priv->menu_view_toolbar = view_menu_uiinfo[7].widget;
+    main_menu->priv->menu_view_conbuttons = view_menu_uiinfo[8].widget;
+    main_menu->priv->menu_view_concombo = view_menu_uiinfo[9].widget;
+    main_menu->priv->menu_view_cmdline = view_menu_uiinfo[10].widget;
+    main_menu->priv->menu_view_buttonbar = view_menu_uiinfo[11].widget;
+    main_menu->priv->menu_view_hidden_files = view_menu_uiinfo[13].widget;
+    main_menu->priv->menu_view_backup_files = view_menu_uiinfo[14].widget;
     main_menu->priv->menu_view_back = view_menu_uiinfo[0].widget;
     main_menu->priv->menu_view_forward = view_menu_uiinfo[1].widget;
 
-    gtk_check_menu_item_set_active (
-        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_conbuttons),
-        gnome_cmd_data_get_conbuttons_visibility ());
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_toolbar),
-        gnome_cmd_data_get_toolbar_visibility ());
+        gnome_cmd_data.toolbar_visibility);
+    gtk_check_menu_item_set_active (
+        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_conbuttons),
+        gnome_cmd_data.conbuttons_visibility);
+    gtk_check_menu_item_set_active (
+        GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_concombo),
+        gnome_cmd_data.concombo_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_buttonbar),
-        gnome_cmd_data_get_buttonbar_visibility ());
+        gnome_cmd_data.buttonbar_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_cmdline),
-        gnome_cmd_data_get_cmdline_visibility ());
+        gnome_cmd_data.cmdline_visibility);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_hidden_files),
-        !gnome_cmd_data_get_hidden_filter ());
+        !gnome_cmd_data.filter_settings.hidden);
     gtk_check_menu_item_set_active (
         GTK_CHECK_MENU_ITEM (main_menu->priv->menu_view_backup_files),
-        !gnome_cmd_data_get_backup_filter ());
+        !gnome_cmd_data.filter_settings.backup);
 
     gtk_signal_connect (GTK_OBJECT (gnome_cmd_con_list_get ()), "list-changed",
                         GTK_SIGNAL_FUNC (on_con_list_list_changed), main_menu);
@@ -862,13 +875,13 @@ static void init (GnomeCmdMainMenu *main_menu)
  * Public functions
  ***********************************/
 
-GtkWidget *gnome_cmd_main_menu_new (void)
+GtkWidget *gnome_cmd_main_menu_new ()
 {
     return (GtkWidget *) gtk_type_new (gnome_cmd_main_menu_get_type ());
 }
 
 
-GtkType gnome_cmd_main_menu_get_type (void)
+GtkType gnome_cmd_main_menu_get_type ()
 {
     static GtkType dlg_type = 0;
 
@@ -910,11 +923,11 @@ void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
     GtkMenuShell *connections_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
     GnomeCmdConList *con_list = gnome_cmd_con_list_get ();
     GList *all_cons = gnome_cmd_con_list_get_all (con_list);
-    GList *ftp_cons = gnome_cmd_con_list_get_all_ftp (con_list);
-    GList *dev_cons = gnome_cmd_con_list_get_all_dev (con_list);
+    // GList *ftp_cons = gnome_cmd_con_list_get_all_ftp (con_list);
+    // GList *dev_cons = gnome_cmd_con_list_get_all_dev (con_list);
 
     // Remove all old items
-    g_list_foreach (main_menu->priv->connections_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->connections_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->connections_menuitems);
     main_menu->priv->connections_menuitems = NULL;
 
@@ -961,12 +974,12 @@ void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
     // Remove all old bookmark menu items
-    g_list_foreach (main_menu->priv->bookmark_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->bookmark_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->bookmark_menuitems);
     main_menu->priv->bookmark_menuitems = NULL;
 
     // Remove all old group menu items
-    g_list_foreach (main_menu->priv->group_menuitems, (GFunc)gtk_widget_destroy, NULL);
+    g_list_foreach (main_menu->priv->group_menuitems, (GFunc) gtk_widget_destroy, NULL);
     g_list_free (main_menu->priv->group_menuitems);
     main_menu->priv->group_menuitems = NULL;
 
@@ -977,7 +990,7 @@ void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
         GnomeCmdCon *con = GNOME_CMD_CON (cons->data);
         GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
         GtkMenuShell *bookmarks_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->bookmarks_menu)->submenu);
-        if (group->bookmarks)
+        if (group && group->bookmarks)
             add_bookmark_group (main_menu, bookmarks_menu, group);
     }
 }
@@ -989,8 +1002,8 @@ void gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu)
 
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
 
-    gtk_widget_set_sensitive (main_menu->priv->menu_view_back, gnome_cmd_file_selector_can_back (fs));
-    gtk_widget_set_sensitive (main_menu->priv->menu_view_forward, gnome_cmd_file_selector_can_forward (fs));
+    gtk_widget_set_sensitive (main_menu->priv->menu_view_back, fs->can_back());
+    gtk_widget_set_sensitive (main_menu->priv->menu_view_forward, fs->can_forward());
 }
 
 
