@@ -5,6 +5,7 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
+        Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,8 +24,6 @@
 
 #include <config.h>
 
-#include <iostream>
-
 #include <errno.h>
 #include <unistd.h>
 #include <string.h>
@@ -34,13 +33,17 @@
 #include <gtk/gtkadjustment.h>
 #include <gtk/gtkmarshal.h>
 
+#include <iostream>
+
 #include "image-render.h"
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file.h"
 #include "utils.h"
 
+using namespace std;
 
-static GtkWidget *parent_class = NULL;
+
+static GtkWidgetClass *parent_class = NULL;
 
 enum {
   IMAGE_STATUS_CHANGED,
@@ -51,7 +54,7 @@ static guint image_render_signals[LAST_SIGNAL] = { 0 };
 
 
 // Class Private Data
-struct _ImageRenderPrivate
+struct ImageRenderPrivate
 {
     guint8 button; // The button pressed in "button_press_event"
 
@@ -113,7 +116,7 @@ static void image_render_update_adjustments (ImageRender *obj);
     public functions
     (defined in the header file)
 *****************************************/
-GtkType image_render_get_type (void)
+GtkType image_render_get_type ()
 {
     static GtkType type = 0;
     if (type == 0)
@@ -135,7 +138,7 @@ GtkType image_render_get_type (void)
 }
 
 
-GtkWidget *image_render_new (void)
+GtkWidget *image_render_new ()
 {
     ImageRender *w = (ImageRender *) gtk_type_new (image_render_get_type ());
 
@@ -151,7 +154,7 @@ void image_render_set_h_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
     if (obj->priv->h_adjustment)
     {
         gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->h_adjustment), (gpointer) obj);
-        gtk_object_unref (GTK_OBJECT (obj->priv->h_adjustment));
+        g_object_unref (obj->priv->h_adjustment);
     }
 
     obj->priv->h_adjustment = adjustment;
@@ -180,7 +183,7 @@ void image_render_set_v_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
     if (obj->priv->v_adjustment)
     {
         gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->v_adjustment), (gpointer) obj);
-        gtk_object_unref (GTK_OBJECT (obj->priv->v_adjustment));
+        g_object_unref (obj->priv->v_adjustment);
     }
 
     obj->priv->v_adjustment = adjustment;
@@ -203,10 +206,10 @@ void image_render_set_v_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
 
 static void image_render_class_init (ImageRenderClass *klass)
 {
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    parent_class = (GtkWidget *) gtk_type_class (gtk_widget_get_type ());
+    parent_class = (GtkWidgetClass *) gtk_type_class (gtk_widget_get_type ());
 
     object_class->destroy = image_render_destroy;
 
@@ -223,7 +226,7 @@ static void image_render_class_init (ImageRenderClass *klass)
     widget_class->realize = image_render_realize;
 
     image_render_signals[IMAGE_STATUS_CHANGED] =
-        gtk_signal_new ("image_status_changed",
+        gtk_signal_new ("image-status-changed",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
             GTK_SIGNAL_OFFSET (ImageRenderClass, image_status_changed),
@@ -290,11 +293,11 @@ static void image_render_destroy (GtkObject *object)
             image_render_free_pixbuf (w);
 
             if (w->priv->v_adjustment)
-                gtk_object_unref (GTK_OBJECT(w->priv->v_adjustment));
+                g_object_unref (w->priv->v_adjustment);
             w->priv->v_adjustment = NULL;
 
             if (w->priv->h_adjustment)
-                gtk_object_unref (GTK_OBJECT(w->priv->h_adjustment));
+                g_object_unref (w->priv->h_adjustment);
             w->priv->h_adjustment = NULL;
 
             g_free (w->priv);
@@ -341,12 +344,11 @@ static void image_render_realize (GtkWidget *widget)
     g_return_if_fail (widget != NULL);
     g_return_if_fail (IS_IMAGE_RENDER (widget));
 
-    GdkWindowAttr attributes;
-    gint attributes_mask;
-
     GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
     ImageRender *obj = IMAGE_RENDER (widget);
 
+    GdkWindowAttr attributes;
+
     attributes.x = widget->allocation.x;
     attributes.y = widget->allocation.y;
     attributes.width = widget->allocation.width;
@@ -360,7 +362,7 @@ static void image_render_realize (GtkWidget *widget)
     attributes.visual = gtk_widget_get_visual (widget);
     attributes.colormap = gtk_widget_get_colormap (widget);
 
-    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+    gint attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
     widget->window = gdk_window_new (widget->parent->window, &attributes, attributes_mask);
 
     widget->style = gtk_style_attach (widget->style, widget->window);
