@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -363,32 +364,27 @@ void gcmd_tags_exiv2_init()
 }
 
 
-void gcmd_tags_exiv2_shutdown()
+void gcmd_tags_exiv2_load_metadata(GnomeCmdFile *f)
 {
-}
+    g_return_if_fail (f != NULL);
+    g_return_if_fail (f->info != NULL);
 
+    if (f->metadata && f->metadata->is_accessed(TAG_IMAGE))  return;
 
-void gcmd_tags_exiv2_load_metadata(GnomeCmdFile *finfo)
-{
-    g_return_if_fail (finfo != NULL);
-    g_return_if_fail (finfo->info != NULL);
+    if (!f->metadata)
+        f->metadata = new GnomeCmdFileMetadata;
 
-    if (finfo->metadata && finfo->metadata->is_accessed(TAG_IMAGE))  return;
+    if (!f->metadata)  return;
 
-    if (!finfo->metadata)
-        finfo->metadata = new GnomeCmdFileMetadata;
-
-    if (!finfo->metadata)  return;
-
-    finfo->metadata->mark_as_accessed(TAG_IMAGE);
+    f->metadata->mark_as_accessed(TAG_IMAGE);
 #ifdef HAVE_EXIV2
-    finfo->metadata->mark_as_accessed(TAG_EXIF);
-    finfo->metadata->mark_as_accessed(TAG_IPTC);
+    f->metadata->mark_as_accessed(TAG_EXIF);
+    f->metadata->mark_as_accessed(TAG_IPTC);
 #endif
 
-    if (!gnome_cmd_file_is_local(finfo))  return;
+    if (!gnome_cmd_file_is_local(f))  return;
 
-    gchar *fname = gnome_cmd_file_get_real_path(finfo);
+    gchar *fname = gnome_cmd_file_get_real_path (f);
 
     DEBUG('t', "Loading image metadata for '%s'\n", fname);
 
@@ -399,8 +395,8 @@ void gcmd_tags_exiv2_load_metadata(GnomeCmdFile *finfo)
 
         image->readMetadata();
 
-        readTags(finfo->metadata, image->exifData());
-        readTags(finfo->metadata, image->iptcData());
+        readTags(f->metadata, image->exifData());
+        readTags(f->metadata, image->iptcData());
     }
 
     catch (AnyError &e)
@@ -416,6 +412,6 @@ void gcmd_tags_exiv2_load_metadata(GnomeCmdFile *finfo)
     if (!fmt)
         return;
 
-    finfo->metadata->addf (TAG_IMAGE_WIDTH, "%i", width);
-    finfo->metadata->addf (TAG_IMAGE_HEIGHT, "%i", height);
+    f->metadata->addf (TAG_IMAGE_WIDTH, "%i", width);
+    f->metadata->addf (TAG_IMAGE_HEIGHT, "%i", height);
 }
